@@ -32,7 +32,8 @@ extern "C" {
 	       SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
 	       SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
 	       SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
-	       SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r){
+	       SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, SEXP fixedSigmaSq_r, 
+	       SEXP sigmaSqIG_r){
    
     /**********************************************************************
      * Initial constants
@@ -110,6 +111,8 @@ extern "C" {
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
     int thinIndx = 0; 
+    int fixedSigmaSq = INTEGER(fixedSigmaSq_r)[0];
+    int sigmaSqIG = INTEGER(sigmaSqIG_r)[0];
     int sPost = 0; 
 
 #ifdef _OPENMP
@@ -313,7 +316,7 @@ extern "C" {
     double *accept = (double *) R_alloc(nTheta, sizeof(double)); zeros(accept, nTheta); 
     double *theta = (double *) R_alloc(nTheta, sizeof(double));
     double logMHRatio, logPostCurr = 0.0, logPostCand = 0.0, detCand = 0.0, detCurr = 0.0;
-    double phiCand = 0.0, nuCand = 0.0;  
+    double phiCand = 0.0, nuCand = 0.0, sigmaSqCand = 0.0;  
     SEXP acceptSamples_r; 
     PROTECT(acceptSamples_r = allocMatrix(REALSXP, nTheta, nBatch)); nProtect++; 
     SEXP tuningSamples_r; 
@@ -323,6 +326,7 @@ extern "C" {
     // Initiate spatial values
     theta[sigmaSqIndx] = REAL(sigmaSqStarting_r)[0]; 
     double phi = REAL(phiStarting_r)[0]; 
+    double sigmaSq = theta[sigmaSqIndx];
     theta[phiIndx] = phi; 
     if (corName == "matern") {
       theta[nuIndx] = nu; 
@@ -332,7 +336,9 @@ extern "C" {
     double *tmp_JD = (double *) R_alloc(J, sizeof(double));
     double *tmp_JD2 = (double *) R_alloc(J, sizeof(double));
     double *R = (double *) R_alloc(JJ, sizeof(double)); 
-    spCorLT(coordsD, J, theta, corName, R); 
+    if (sigmaSqIG) {
+      spCorLT(coordsD, J, theta, corName, R); 
+    }
     logPostCurr = R_NegInf; 
     spCovLT(coordsD, J, theta, corName, C); 
     F77_NAME(dpotrf)(lower, &J, C, &J, &info FCONE); 
@@ -438,7 +444,6 @@ extern "C" {
             tmp_nObs[i] *= z[zLongIndx[i]]; 
           } // i
         }
-        
         F77_NAME(dgemv)(ytran, &nObs, &pDet, &one, Xp, &nObs, tmp_nObs, &inc, &zero, tmp_pDet, &inc FCONE); 	  
         for (j = 0; j < pDet; j++) {
           tmp_pDet[j] += SigmaAlphaInvMuAlpha[j]; 
@@ -561,25 +566,29 @@ extern "C" {
 	/********************************************************************
          *Update sigmaSq
          *******************************************************************/
-	// Get inverse correlation matrix in reverse from inverse covariance matrix
-	// Remember: C currently contains the inverse of covariance matrix. 
-	fillUTri(C, J); 
-	for (j = 0; j < JJ; j++) {
-          R[j] = theta[sigmaSqIndx] * C[j]; 
-	} // j
-	// Compute t(w) %*% R^-1 %*% w / 
-	// t(w) %*% R^-1
-	// Def a better way to do this operation. 
-	for (j = 0; j < J; j++) {
-          wTRInv[j] = F77_NAME(ddot)(&J, &R[j], &J, w, &inc);  
-        } // j
-	bSigmaSqPost = F77_NAME(ddot)(&J, wTRInv, &inc, w, &inc); 
-	bSigmaSqPost /= 2.0; 
-	bSigmaSqPost += sigmaSqB; 
-	theta[sigmaSqIndx] = rigamma(aSigmaSqPost, bSigmaSqPost); 
+	if (!fixedSigmaSq) {
+          if (sigmaSqIG) {
+	    // Get inverse correlation matrix in reverse from inverse covariance matrix
+	    // Remember: C currently contains the inverse of covariance matrix. 
+	    fillUTri(C, J); 
+	    for (j = 0; j < JJ; j++) {
+              R[j] = theta[sigmaSqIndx] * C[j]; 
+	    } // j
+	    // Compute t(w) %*% R^-1 %*% w / 
+	    // t(w) %*% R^-1
+	    // Def a better way to do this operation. 
+	    for (j = 0; j < J; j++) {
+              wTRInv[j] = F77_NAME(ddot)(&J, &R[j], &J, w, &inc);  
+            } // j
+	    bSigmaSqPost = F77_NAME(ddot)(&J, wTRInv, &inc, w, &inc); 
+	    bSigmaSqPost /= 2.0; 
+	    bSigmaSqPost += sigmaSqB; 
+	    theta[sigmaSqIndx] = rigamma(aSigmaSqPost, bSigmaSqPost); 
+	  }
+	}
 
         /********************************************************************
-         *Update phi (and nu if matern)
+         *Update phi (and nu if matern and sigmaSq if uniform prior)
          *******************************************************************/
 	if (corName == "matern") {
           nu = theta[nuIndx]; 
@@ -589,6 +598,12 @@ extern "C" {
 	phi = theta[phiIndx]; 
 	phiCand = logitInv(rnorm(logit(phi, phiA, phiB), exp(tuning[phiIndx])), phiA, phiB); 
 	theta[phiIndx] = phiCand; 
+	if (sigmaSqIG == 0) {
+	  sigmaSq = theta[sigmaSqIndx]; 
+	  sigmaSqCand = logitInv(rnorm(logit(sigmaSq, sigmaSqA, sigmaSqB), 
+				 exp(tuning[sigmaSqIndx])), sigmaSqA, sigmaSqB); 
+	  theta[sigmaSqIndx] = sigmaSqCand; 
+	}
 
 	// Construct covariance matrix (stored in C). 
 	spCovLT(coordsD, J, theta, corName, CCand); 
@@ -615,6 +630,9 @@ extern "C" {
         if (corName == "matern"){
           logPostCand += log(nuCand - nuA) + log(nuB - nuCand); 
         }
+	if (sigmaSqIG == 0) {
+          logPostCand += log(sigmaSqCand - sigmaSqA) + log(sigmaSqB - sigmaSqCand);
+	}
 
         /********************************
          * Current
@@ -623,6 +641,9 @@ extern "C" {
 	  theta[nuIndx] = nu; 
 	}
 	theta[phiIndx] = phi; 
+	if (sigmaSqIG == 0) {
+          theta[sigmaSqIndx] = sigmaSq;
+	}
 	spCovLT(coordsD, J, theta, corName, C); 
         detCurr = 0.0;
 	F77_NAME(dpotrf)(lower, &J, C, &J, &info FCONE); 
@@ -640,6 +661,9 @@ extern "C" {
         if (corName == "matern"){
           logPostCurr += log(nu - nuA) + log(nuB - nu); 
         }
+	if (sigmaSqIG == 0) {
+          logPostCurr += log(sigmaSq - sigmaSqA) + log(sigmaSqB - sigmaSq);
+	}
 
 	// MH Accept/Reject
 	logMHRatio = logPostCand - logPostCurr; 
@@ -650,6 +674,10 @@ extern "C" {
             theta[nuIndx] = nuCand; 
             accept[nuIndx]++; 
           }
+	  if (sigmaSqIG == 0) {
+            theta[sigmaSqIndx] = sigmaSqCand;
+	    accept[sigmaSqIndx]++;
+	  }
 	  F77_NAME(dcopy)(&JJ, CCand, &inc, C, &inc); 
         }
 	
@@ -782,8 +810,14 @@ extern "C" {
       if (verbose) {
 	if (status == nReport) {
 	  Rprintf("Batch: %i of %i, %3.2f%%\n", s, nBatch, 100.0*s/nBatch);
-	  Rprintf("\tAcceptance\tTuning\n");	  
-	  Rprintf("\t%3.1f\t\t%1.5f\n", 100.0*REAL(acceptSamples_r)[s * nTheta + phiIndx], exp(tuning[phiIndx]));
+	  Rprintf("\tParameter\tAcceptance\tTuning\n");	  
+	  Rprintf("\tphi\t\t%3.1f\t\t%1.5f\n", 100.0*REAL(acceptSamples_r)[s * nTheta + phiIndx], exp(tuning[phiIndx]));
+	  if (corName == "matern") {
+	    Rprintf("\tnu\t\t%3.1f\t\t%1.5f\n", 100.0*REAL(acceptSamples_r)[s * nTheta + nuIndx], exp(tuning[nuIndx]));
+	  }
+	  if (sigmaSqIG == 0) {
+	    Rprintf("\tsigmaSq\t\t%3.1f\t\t%1.5f\n", 100.0*REAL(acceptSamples_r)[s * nTheta + sigmaSqIndx], exp(tuning[sigmaSqIndx]));
+	  }
 	  Rprintf("-------------------------------------------------\n");
           #ifdef Win32
 	  R_FlushConsole();
